import express from "express";
import PermissionHelper from "../../helpers/permissionHelper";

import award from "./settings/award";
import communicationType from "./settings/communicationType";
import executivePosition from "./settings/executivePosition";
import membershipStatus from "./settings/membershipStatus";
import qualification from "./settings/qualification";
import salutation from "./settings/salutation";
import calendarType from "./settings/calendarType";
import queryStore from "./settings/queryStore";
import template from "./settings/template";
import templateUsage from "./settings/templateUsage";
import newsletterConfig from "./settings/newsletterConfig";

import member from "./club/member";
import protocol from "./club/protocol";
import calendar from "./club/calendar";
import queryBuilder from "./club/queryBuilder";
import newsletter from "./club/newsletter";

import role from "./user/role";
import user from "./user/user";
import invite from "./user/invite";
import api from "./user/webapi";
import preventWebapiAccess from "../../middleware/preventWebApiAccess";

var router = express.Router({ mergeParams: true });

router.use(
  "/award",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "award" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  award
);
router.use(
  "/communicationtype",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "communication_type" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  communicationType
);
router.use(
  "/executiveposition",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "executive_position" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  executivePosition
);
router.use(
  "/membershipstatus",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "membership_status" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  membershipStatus
);
router.use(
  "/qualification",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "qualification" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  qualification
);
router.use(
  "/salutation",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "salutation" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  salutation
);
router.use(
  "/calendartype",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "calendar_type" },
    { requiredPermissions: "read", section: "club", module: "calendar" },
  ]),
  calendarType
);
router.use("/querystore", PermissionHelper.passCheckMiddleware("read", "settings", "query_store"), queryStore);
router.use("/template", PermissionHelper.passCheckMiddleware("read", "settings", "template"), template);
router.use(
  "/templateusage",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "template_usage" },
    { requiredPermissions: "read", section: "settings", module: "template" },
  ]),
  templateUsage
);
router.use(
  "/newsletterconfig",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "settings", module: "newsletter_config" },
    { requiredPermissions: "read", section: "settings", module: "communication_type" },
  ]),
  newsletterConfig
);

router.use("/member", PermissionHelper.passCheckMiddleware("read", "club", "member"), member);
router.use(
  "/protocol",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "club", module: "protocol" },
    { requiredPermissions: "read", section: "club", module: "member" },
  ]),
  protocol
);
router.use("/calendar", PermissionHelper.passCheckMiddleware("read", "club", "calendar"), calendar);
router.use(
  "/querybuilder",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "club", module: "query" },
    { requiredPermissions: "read", section: "settings", module: "query_store" },
  ]),
  queryBuilder
);
router.use(
  "/newsletter",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "club", module: "newsletter" },
    { requiredPermissions: "read", section: "club", module: "member" },
    { requiredPermissions: "read", section: "club", module: "calendar" },
    { requiredPermissions: "read", section: "club", module: "query" },
    { requiredPermissions: "read", section: "settings", module: "query_store" },
  ]),
  newsletter
);

router.use("/role", PermissionHelper.passCheckMiddleware("read", "user", "role"), role);
router.use(
  "/user",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "user", module: "user" },
    { requiredPermissions: "read", section: "user", module: "role" },
  ]),
  user
);
router.use("/invite", PermissionHelper.passCheckMiddleware("read", "user", "user"), invite);
router.use("/webapi", preventWebapiAccess, PermissionHelper.passCheckMiddleware("read", "user", "webapi"), api);

export default router;
